import os
import sys

from loguru import logger


async def load_extensions(bot, folder: str):
    try:
        logger.info("Load modules...")
        src_directory = os.path.join(folder)
        sys.path.append(src_directory)
        
        for directory in os.listdir(src_directory):
            directory_path = os.path.join(src_directory, directory)

            if os.path.isdir(directory_path) and directory != "utils":
                for filename in os.listdir(directory_path):
                    bot.load_extension(f"{directory}.{filename[:-3]}")
                    logger.info("Starting bot...")

    except Exception as e:
        logger.error(f"Произошла ошибка при загрузке модулей\n╰─> Ошибка: {e}")



from .Reader import read_env, read_json, write_json
from .Loguru import logger
from .Cogs import load_extensions

from .Embed import embed_success, embed_error, green, red, blue, yellow, transparent

from .Tortoise import Database



from loguru import logger
from aiofiles import open
from fastenv import load_dotenv
from json import JSONDecodeError, loads, dumps


async def read_json(path: str, *keys):
    try:
        async with open(path, mode="r", encoding="utf-8") as file:
            file_content = await file.read()
            file_data = loads(file_content)

            if keys:
                for key in keys:
                    if key not in file_data:
                        logger.error(f"Ключ: {key} не найден в файле {path}")
                        return None
                    
                    file_data = file_data[key]

                return file_data
            else:
                return file_data
    
    except FileNotFoundError as e:
        logger.error(f"Указанный файл по пути: {path} не найден\n╰─> Ошибка: {e}")
    except JSONDecodeError as e:
        logger.error(f"Ошибка в файле: {path}\n╰─> Ошибка: {e}")
    except Exception as e:
        logger.error(f"Произошла неизвестная ошибка при чтений файла: {path}\n╰─> Ошибка: {e}")


async def write_json(path: str, data: dict, encoding="utf-8"):
    async with open(path, mode="w", encoding=encoding) as file:
        await file.write(dumps(data, ensure_ascii=False, indent=2))


async def read_env(path):
    bot_settings = await load_dotenv(path)
    return bot_settings



import os
import sys

from loguru import logger
from datetime import datetime

os.makedirs("settings/logs", exist_ok=True)

log_file_path = os.path.join("settings/logs", f"{datetime.now().strftime('%Y-%m-%d')}.log")
logger.remove(0)

logger.add(
    sys.stderr,
    format="<blue>[{time:HH:mm:ss}]</blue> <yellow>({level})</yellow> <red>|→</red> <green>{message}</green>",
    colorize=True,
    level="INFO",
    filter=lambda record: record["level"].name == "INFO",
)

logger.add(
    sys.stderr,
    format="<blue>[{time:HH:mm:ss}]</blue> <yellow>({level})</yellow> |> <yellow>{message}</yellow>",
    colorize=True,
    level="WARNING",
    filter=lambda record: record["level"].name == "WARNING",
)

logger.add(
    sys.stderr,
    format="<blue>[{time:HH:mm:ss}]</blue> <red>({level})|→ {message}</red>",
    colorize=True,
    level="ERROR",
    filter=lambda record: record["level"].name == "ERROR"
)

logger.add(
    log_file_path,
    format="{time:MMMM D, YYYY > HH:mm:ss} | {level} | {file}:{line} - {message}",
    level="ERROR",
    enqueue=True,
    rotation="1 day",
    retention="7 day"
)



import os

from loguru import logger
from tortoise import Tortoise


class Database:
    def __init__(self):
        self.db_path = "sqlite://settings/database/bot.db"
        self.db_models = {"models": [os.path.join("src.utils")]}


    async def database_connect(self):
        try:
            logger.info("Database connected")
            await Tortoise.init(db_url=self.db_path, modules=self.db_models)
            await Tortoise.generate_schemas()
        except Exception as e:
            logger.error(f"Ошибка подключение к базе данных\n╰─> Ошибка: {e}")


    async def database_close(self):
        logger.error("Database disconnected")
        await Tortoise.close_connections()



from nextcord import Embed, Forbidden, Color


red = Color.from_rgb(255, 0, 0)
green = Color.from_rgb(0, 255, 0)
blue = Color.from_rgb(0, 0, 255)
yellow = Color.from_rgb(255, 255, 0)
transparent = Color.from_rgb(43, 45, 49)


async def embed_generate(title, description, emoji):
    embed_generate = Embed(color=green)
    embed_generate.set_author(name=f"{emoji} {title}")
    embed_generate.description = description
    return embed_generate


async def embed_success(title, description, id, bot, emoji="✅", content=None, guild=True):
    try:
        embed_data = await embed_generate(title, description, emoji)

        if guild:
            sending = await bot.fetch_channel(id)
        else:
            sending = await bot.fetch_user(id)

        await sending.send(content=content, embed=embed_data)

        return True
    
    except Forbidden:
        return False


async def embed_error(title, description, id, bot, emoji="❌", content=None, guild=True):
    try:
        embed_data = await embed_generate(title, description, emoji)

        if guild:
            sending = await bot.fetch_channel(id)
        else:
            sending = await bot.fetch_user(id)

        await sending.send(content=content, embed=embed_data)

        return True
    except Forbidden:
        return False



from setuptools import setup, find_packages

setup(
    name="crx-utils",
    version="1.1.0",
    description="A collection of functions for creating Discord bots, works with nextcord.",
    url="https://discord.gg/EEp67FWQDP",
    author="CRX-DEV",
    author_email="cherniq66@gmail.com",
    license="MIT License",
    packages=find_packages(include=['crx', 'crx.*']),
    install_requires=[
        "tortoise-orm==0.21.0",
        "nextcord==2.6.0",
        "aiofiles==23.2.1",
        "fastenv==0.5.0",
        "loguru==0.7.2",
    ]
)
